==> sitecheck-0.8.0-py3-none-any.whl: sitecheck/scanner/Scanner/pyppet/sites.py <==
"""
    Shared functions for pyppet

    Currently Supported Sites:
    Amp - <project.name>.geo-instruments.com/index.php
    Quickview - https://quickview.geo-instruments.com/login.php
    Truelook (Dev branch) - https://app.truelook.com/<project specific>
"""
# __author__ = DanEdens
# __status__  = "production"

import os

import pyppeteer.errors
from pyppeteer import launch

from sitecheck.scanner.Scanner import options
from sitecheck.scanner.Scanner.pyppet import text


async def make_browser():
    """
    Creates a new Browser context

    Returns: browser Object

    """
    browser = await launch({"headless": options.headless, "ignoreHTTPSErrors": True},
                           args=options.chrome_args)
    return browser


async def login(self):
    """
    Handles AMP and QV Authentication.

    :rtype: None
    """
    await self.page.goto(self.url)
    await self.page.waitFor(2000)
    for x in [text.Amp_text, text.Qv_text]:
        try:
            await self.page.type(x.logincss, x.username)
            await self.page.type(x.pwcss, x.password)
            await self.page.click(x.loginbutton)
        except pyppeteer.errors.PageError:
            pass
    await self.page.waitFor(200)


async def scan_plan_view(parent, operator):
    """
    Iterate through Array of possible Sensor selectors on current planview.

    Absolute selector:
        'body > div:nth-child('(3:4)') > div:nth-child('(0:300)') > a:nth-child(1)'
    Relative selector:
        'body >' + amp.csspath + type_of_sensor_box + ') ' + csspath + self.target_child + amp.title

    :param parent: <projecthandler.Project_runner object at ** >
    :param operator: <class 'pyppet.sites.Amp_Webpage'>

    """
    for target_child in range(0, 300):
        os.environ['TARGET_CHILD'] = str(target_child)
        await operator.get_last_update(parent)

==> sitecheck-0.8.1.2-py3-none-any.whl: sitecheck/scanner/Scanner/pyppet/sites.py <==
"""
    Shared functions for Scanner.pyppet module

    Currently Supported Sites:
    Amp - <project.name>.geo-instruments.com/index.php
    Quickview - https://quickview.geo-instruments.com/login.php
    Truelook (Dev branch) - https://app.truelook.com/<project specific>
"""
import os

import pyppeteer.errors
from pyppeteer import launch

from sitecheck.scanner.Scanner import options
from sitecheck.scanner.Scanner.pyppet import text
from sitecheck.scanner.Scanner.pyppet import utlis


async def make_browser():
    """
    Creates a new Browser context

    Returns: browser Object

    """
    browser = await launch(
        {"headless": options.headless, "ignoreHTTPSErrors": True},
        args=options.chrome_args)
    return browser


async def login(self):
    """
    Handles AMP and QV Authentication.

    :rtype: None
    """
    await self.page.goto(self.url)
    await utlis.wait_count(self, 2)
    for x in [text.Amp_text, text.Qv_text]:
        try:
            await self.page.type(x.logincss, x.username)
            await self.page.type(x.pwcss, x.password)
            await self.page.click(x.loginbutton)
        except pyppeteer.errors.PageError:
            pass
    await self.page.waitFor(200)


async def scan_plan_view(parent, operator):
    """
    Iterate through Array of possible Sensor selectors on current planview.

    Absolute selector:
        'body > div:nth-child('(3:4)') > div:nth-child('(0:300)') > a:nth-child(1)'
    Relative selector:
        'body >' + amp.csspath + type_of_sensor_box + ') ' + csspath + self.target_child + amp.title

    :param parent: <projecthandler.Project_runner object at ** >
    :param operator: <class 'pyppet.sites.Amp_Webpage'>

    """
    for target_child in range(0, 300):
        os.environ['TARGET_CHILD'] = str(target_child)
        await operator.get_last_update(parent)
